==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/iboundedplanesource.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IBOUNDEDPLANESOURCE_H
#define IBOUNDEDPLANESOURCE_H


#include "iboundedpolydatasource.h"


class vtkPlaneSource;


class iBoundedPlaneSource : public iBoundedPolyDataSource
{

public:
	
	static iBoundedPlaneSource* New(iViewObject *vo);

protected:
	
	iBoundedPlaneSource(iViewObject *vo);
	virtual ~iBoundedPlaneSource();

	virtual void UpdateBoundaryConditions();
	virtual void UpdateSourceResolution();
	virtual void AddObserverToSource(unsigned long e, vtkCommand *c, float priority);
	virtual float GetSourceMemorySize() const;

	//
	//  VTK stuff
	//
	vtkPlaneSource *mSource;
};

#endif // IBOUNDEDPLANESOURCE_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/iboundedplanesource.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IBOUNDEDPLANESOURCE_H
#define IBOUNDEDPLANESOURCE_H


#include "iboundedpolydatasource.h"


class vtkPlaneSource;


class iBoundedPlaneSource : public iBoundedPolyDataSource
{

public:
	
	static iBoundedPlaneSource* New(iViewSubject *vo);

protected:
	
	iBoundedPlaneSource(iViewSubject *vo);
	virtual ~iBoundedPlaneSource();

	virtual void UpdateBoundaryConditions();
	virtual void UpdateSourceResolution();
	virtual void AddObserverToSource(unsigned long e, vtkCommand *c, float priority);
	virtual float GetSourceMemorySize() const;

	//
	//  VTK stuff
	//
	vtkPlaneSource *mSource;
};

#endif // IBOUNDEDPLANESOURCE_H
